#!/usr/bin/env python

from distutils.core import setup
import os

setup(name='touchsearch-youtube',
   version='1.0',
   data_files = [
      ('/opt/touchsearch/search_engines/YouTube/',['YouTube.search', 'youtube_color.png', 'youtube_ghosted.png'])
      ]
      )